@@ -6,11 +6,12 @@ use Carp;
 use MRO::Compat;
 use mro 'c3';
 use Data::Dump qw( dump );
+use Try::Tiny;
 
 __PACKAGE__->mk_accessors(qw( enable_rpc_compat ));
 __PACKAGE__->config( enable_rpc_compat => 0 );
 
-our $VERSION = '0.56';
+our $VERSION = '0.58';
 
 #warn "REST VERSION = $VERSION";
 
@@ -263,8 +264,12 @@ sub _rest {
     my $rpc = shift @arg;
 
     my $http_method = $self->req_method($c);
-    $c->log->debug("rest OID:$oid  rpc:$rpc  http:$http_method")
-        if $c->debug;
+    $c->log->debug(
+        sprintf(
+            "rest OID:%s  rpc:%s  http:%s",
+            $oid, ( $rpc || '[undef]' ), $http_method
+        )
+    ) if $c->debug;
 
     if ( length $oid and $rpc ) {
         if ( $self->enable_rpc_compat and exists $rpc_methods{$rpc} ) {
@@ -313,7 +318,20 @@ sub _rest {
 sub _call_rpc_method_as_action {
     my ( $self, $c, $rpc_method, $oid ) = @_;
 
-    $self->fetch( $c, $oid );
+    my $break_chain = 0;
+    try {
+        $self->fetch( $c, $oid );
+    }
+    catch {
+        $c->log->debug( 'caught exception, res->status==' . $c->res->status )
+            if $c->debug;
+        if ( $c->res->status == 404 ) {
+            $c->log->debug('break chain with 404') if $c->debug;
+            $break_chain = 1;
+        }
+    };
+
+    return if $break_chain;
 
     my $http_method = $self->req_method($c);
 
@@ -501,6 +519,10 @@ You can also look for information at:
 
 =over 4
 
+=item * Mailing List
+
+L<https://groups.google.com/forum/#!forum/catalystxcrud>
+
 =item * AnnoCPAN: Annotated CPAN documentation
 
 L<http://annocpan.org/dist/CatalystX-CRUD>
